@@ -108,7 +108,7 @@ Its value should be 'always or list like (filename run compile).")
            "f77 %f -o %n" "./%n" "%n")
     (php   (or (name . "\\.php$")
                (mode . php-mode))
-           "php %f" "php %f")
+           "php -l %f" "php %f")
     (elisp (or (name . "\\.el$")
                (mode . emacs-lisp-mode)
                (mode . lisp-interaction-mode))
